/* -------------------------------------------------------------------

	Title:
		RandomGen;

	Purpose:
		Provides randomly or distributed random numbers, using the
		Macintosh's random number generator as a starting point.
		
	Author:
		Stephen Wardlaw, M.D.
		Dept. of Laboratory Medicine
		Yale University School of Medicine
		462-CB  Y-NHH
		20 York St.
		New Haven, CT  06504

	Edit History:
		17 Jan, 94 - Adapted for MetroWerks C++
		15 Jun, 92 - Created by author for MetroWerks M-2.
		
------------------------------------------------------------------- */

#pragma once


class RandomGen {
	public:
	static void
		InitRandom(long seed);
	// Initializes the random generator with the specified seed.
	
	static double
		NormalDist(double mean, sd);
	// Provides random real numbers distributed in a Gaussian curve with 
	// a mean of 'mean', and having a standard deviation of 'sd'.   
		
	static int
		PoissonInt(double mean);
	// Provides integers from a Poisson distribution about the 'mean'. 
	
	static double 
		RandomGauss();
	// Provides random numbers in a gaussian distribution.  The mean value
	// is 0, and the SD of the distribution is 1.0.
		
	static double
		RandomReal();
	// Provides random real numbers from 0.0 to 1.0.
	
	private:
	static double
		RandReal();
	static double
		Ran0(Boolean reset);
		
	static Boolean haveVal;
	static Boolean inited;
	static double gloSet, eFact;
	static double gly;
	static double glv[98];
	static double fact;
	};
	

	